@@ -4,11 +4,11 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw(crypt_type looks_like_crypt);
+our @EXPORT_OK = qw(crypt_type looks_like_crypt crypt);
 
 my $b64d = qr![A-Za-z0-9./]!;
 my $hexd = qr![0-9a-f]!;
@@ -33,6 +33,28 @@ sub crypt_type {
 
 sub looks_like_crypt { !!crypt_type($_[0]) }
 
+sub crypt {
+    require UUID::Random;
+    require Digest::MD5;
+
+    my $pass = shift;
+    my ($salt, $crypt);
+
+    # first use SSHA512
+    $salt  = substr(Digest::MD5::md5_base64(UUID::Random::generate()), 0, 16);
+    $crypt = CORE::crypt($pass, '$6$'.$salt.'$');
+    return $crypt if crypt_type($crypt) eq 'SSHA512';
+
+    # fallback to MD5-CRYPT if failed
+    $salt = substr($salt, 0, 8);
+    $crypt = CORE::crypt($pass, '$1$'.$salt.'$');
+    return $crypt if crypt_type($crypt) eq 'MD5-CRYPT';
+
+    # fallback to CRYPT if failed
+    $salt = substr($salt, 0, 2);
+    CORE::crypt($pass, $salt);
+}
+
 1;
 # ABSTRACT: Crypt password utilities
 
@@ -46,11 +68,11 @@ Crypt::Password::Util - Crypt password utilities
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
- use Crypt::Password::Util qw(crypt_type looks_like_crypt);
+ use Crypt::Password::Util qw(crypt_type looks_like_crypt crypt);
 
  say crypt_type('62F4a6/89.12z');                    # CRYPT
  say crypt_type('$1$$...');                          # MD5-CRYPT
@@ -58,11 +80,13 @@ version 0.05
  say crypt_type('$5$4DdvgCFk$...');                  # SSHA256
  say crypt_type('$6$4DdvgCFk$...');                  # SSHA512
  say crypt_type('1a1dc91c907325c69271ddf0c944bc72'); # PLAIN-MD5
- say crypt_type('foo');                   # undef
+ say crypt_type('foo');                              # undef
 
  say looks_like_crypt('62F4a6/89.12z');   # 1
  say looks_like_crypt('foo');             # 0
 
+ say crypt('pass'); # automatically choose the appropriate type and salt
+
 =head1 FUNCTIONS
 
 =head2 crypt_type($str) => STR
@@ -74,7 +98,14 @@ PLAIN-MD5.
 
 =head2 looks_like_crypt($str) => BOOL
 
-Return true if C<$str> looks like a crypted password. It is
+Return true if C<$str> looks like a crypted password.
+
+=head2 crypt($str) => STR
+
+Like Perl's crypt(), but automatically choose the appropriate crypt type and
+random salt. Will first choose SSHA512 with 64-bit random salt. If not supported
+by system, fall back to MD5-CRYPT with 32-bit random salt. If that is not
+supported, fall back to CRYPT.
 
 =head1 AUTHOR
 
